@@ -7,7 +7,7 @@ from typing import Dict
 
 from . import Command, BaseHandler
 from .commands import RunHttpFileHandler, FormatHttpFileHandler, GetNameReferencesHandler, ImportPostmanCollection, \
-    ContentExecuteHandler, ParseHttpData
+    ContentExecuteHandler, ParseHttpData, ContentNameReferencesHandler
 
 logger = logging.getLogger('handler')
 
@@ -15,7 +15,8 @@ handlers: Dict[str, BaseHandler] = {handler.get_method(): handler for handler in
                                     (FormatHttpFileHandler(), RunHttpFileHandler(), GetNameReferencesHandler(),
                                      ImportPostmanCollection(),
                                      ContentExecuteHandler(),
-                                     ParseHttpData()
+                                     ParseHttpData(),
+                                     ContentNameReferencesHandler()
                                      )}
 
 
