@@ -10,10 +10,13 @@ from requests import PreparedRequest, Session, Response
 from requests.status_codes import _codes as status_code
 from textx import metamodel_from_file
 
-from dothttp.parse_models import Allhttp
-from . import eprint, Config, HttpDefBase
+from . import eprint, Config, HttpDefBase, js3py
 from .curl_utils import to_curl
 from .dsl_jsonparser import json_or_array_to_json
+from .json_utils import JSONEncoder
+from .parse_models import Allhttp
+
+JSON_ENCODER = JSONEncoder(indent=4)
 
 try:
     import magic
@@ -191,8 +194,8 @@ class HttpFileFormatter(RequestBase):
             if payload := http.payload:
                 p = ""
                 mime_type = payload.type
-                if payload.data or payload.multi:
-                    data = payload.data or payload.multi[3:-3]
+                if payload.data:
+                    data = "".join([i.triple[3:-3] if i.triple else i.str for i in payload.data])
                     if '"' in data and "'" not in data:
                         data = f"'{data}'"
                     elif '"' not in data and "'" in data:
@@ -209,7 +212,7 @@ class HttpFileFormatter(RequestBase):
                     p = f'fileinput("{filetype}",{(" ," + mime_type) if mime_type else ""})'
                 elif json_data := payload.json:
                     parsed_data = json_or_array_to_json(json_data, lambda a: a)
-                    p = f'json({json.dumps(parsed_data, indent=4)})'
+                    p = f'json({JSON_ENCODER.encode(parsed_data)})'
                 elif files_wrap := payload.fileswrap:
                     p2 = ",\n\t".join(map(lambda
                                               file_type: f'("{file_type.name}", "{(file_type.path)}"' +
@@ -265,11 +268,37 @@ class RequestCompiler(RequestBase):
     def get_response(self):
         session = self.get_session()
         request = self.get_request()
-        resp: Response = session.send(request)
+        try:
+            resp: Response = session.send(request)
+        except UnicodeEncodeError:
+            # for Chinese, smiley all other default encode converts into latin-1
+            # as latin-1 didn't consist of those characters it will fail
+            # in those scenarios, request will try to encode with utf-8
+            # as a last resort, it may not be correct solution. may be it is.
+            # for now proceeding with this
+            request.prepare_body(request.body.encode("utf-8"), files=None)
+            resp: Response = session.send(request)
         if not self.args.no_cookie and isinstance(session.cookies, LWPCookieJar):
             session.cookies.save()  # lwpCookie has .save method
         return resp
 
+    def execute_script(self, resp: Response):
+        try:
+            content_type = resp.headers.get('content-type', 'text/plain')
+            # in some cases mimetype can have charset
+            # like text/plain; charset=utf-8
+            content_type = content_type.split(";")[0] if ';' in content_type else content_type
+            return js3py.execute_script(
+                is_json=content_type == MIME_TYPE_JSON,
+                script=self.httpdef.test_script,
+                status_code=resp.status_code,
+                headers=dict(resp.headers),
+                properties=self.property_util.get_all_properties_variables(),
+                response_body_text=resp.text,
+            )
+        except Exception as e:
+            request_logger.error(f"unknown exception {e} happened", e)
+
     def print_req_info(self, request: Union[PreparedRequest, Response], prefix=">"):
         if not (self.args.debug or self.args.info):
             return
